from django.conf import settings

FEED_TITLE = getattr(settings, 'FEED_TITLE', 'Site Title')
FEED_LINK = getattr(settings, 'FEED_LINK', 'http://www.example.com')
FEED_DESCRIPTION = getattr(settings, 'FEED_DESCRIPTION', 'Site Description')

BLOG_CATEGORY_PATH = getattr(settings, 'BLOG_CATEGORY_PATH', 'category')
BLOG_TAG_PATH = getattr(settings, 'BLOG_TAG_PATH', 'tag')



from django.contrib import admin
from models import Page
from mptt.admin import MPTTModelAdmin
from django.utils.translation import ugettext_lazy as _
from admin_forms import PageForm
from fancy.utils.admin import BaseAdmin, MetaInline

class PageAdmin(MPTTModelAdmin,BaseAdmin):
    form = PageForm
    
    fieldsets = (
        (None, {
            'fields': ['title','content','parent'],
        }),
        (_('Advanced Options'), {
            'classes':('collapse',),
            'fields':('language','order_number','template','status','show_in_menu','redirect_to','slug')
        })
    )
    list_display = ('title','language','status','order_number')
    list_filter = ['language','status','level']
    list_editable = ('order_number',)
    prepopulated_fields = {"slug": ("title",)}
    search_fields = ['title']
    ordering = ('order_number','title',)

    inlines = [MetaInline]


admin.site.register(Page,PageAdmin)


from django.contrib.sitemaps import Sitemap
from models import Page

class PageSitemap(Sitemap):
    changefreq = "weekly"
    priority = 0.5

    def items(self):
        return Page.objects.filter(status=1)

    def lastmod(self, obj):
        return obj.last_modified





from django.conf.urls.defaults import *


urlpatterns = patterns('fancy.gallery.views',
    url(r'^(?P<slug>[-\w\/]+)/$',
        view='album_detail',
        name='album_detail'
    ),
    url(r'^(?P<album_slug>[-\w\/]+)/(?P<album_item_slug>[-\w\/]+)$',
        view='album_item_detail',
        name='album_item_detail'
    ),
)



# coding=utf-8
from django.contrib import admin
from models import Category, Product
#from fancy.gallery.models import Image
from django.utils.translation import ugettext_lazy as _
from django.db import models
from mptt.admin import MPTTModelAdmin
from fancy.utils.admin import MetaInline, BaseAdmin
from fancy.gallery.admin import ImageInline
from django.contrib.contenttypes import generic
from admin_forms import CategoryForm, ProductForm

class ProductAdmin(BaseAdmin):
    form = ProductForm
    
    list_display  = ['name','category','price','status','order_number']
    search_fields = ['name']
    prepopulated_fields = {"slug": ("name",)}
    list_filter = ['category','status']
    list_editable = ('order_number',)
    ordering = ('order_number', 'id')

    fieldsets = (
        (None, {
            'fields': ['category','name','description',],
        }),
        (_('Extra informations'), {
            'classes':('collapse',),
            'fields': ('price','status','slug','order_number')
        })
    )
    inlines = [ImageInline,MetaInline]

class CategoryAdmin(MPTTModelAdmin,BaseAdmin):
    form = CategoryForm
    list_display = ['name','product_count']
    prepopulated_fields = {"slug": ("name",)}
    inlines = [ImageInline]

    def product_count(self, cat):
        return cat.products.count()
    product_count.admin_field = _('Product count')

admin.site.register(Product, ProductAdmin)
admin.site.register(Category, CategoryAdmin)


from django.shortcuts import render_to_response, get_object_or_404
from django.template import RequestContext
from models import Album, AlbumItem

def album_index(request):
    albums = Album.objects.filter(status=1).order_by('-date_created')
    return render_to_response('fancy/gallery/album_index.html',{'albums':albums},context_instance=RequestContext(request))

def album_detail(request,slug):
    album = get_object_or_404(Album, slug=slug)
    return render_to_response('fancy/gallery/album_detail.html',{'album':album},context_instance=RequestContext(request))



from django.template.defaultfilters import slugify as slugify_original
from django.db.models.signals import post_save
from django.dispatch import receiver
from taggit.models import TaggedItem

def slugify(value):
    value = value.replace(u'\u0131', 'i')
    return slugify_original(value)

@receiver(post_save)
def delete_image_files(sender, instance, **kwargs):
    if sender == TaggedItem:
        instance.tag.slug = slugify(instance.tag.name)
        instance.tag.save()



from django.conf.urls.defaults import *

urlpatterns = patterns('fancy.events.views',
    # events/12/:
    url(r'^$', 'home', name='events_home'),
    url(r'^(?P<id>[\d]+)/$', 'event_detail', name='event_detail'),
)



from django.conf import settings
from django.utils.translation import ugettext_lazy as _

FORM_FROM = getattr(settings, 'FORM_FROM', "noreply@example.com")
FORM_RECIPIENTS = getattr(settings, 'FORM_RECIPIENTS', settings.MANAGERS)
FORM_SUBJECT = getattr(settings, 'FORM_SUBJECT', "Message from site")



from django.db import models
from django.contrib.contenttypes import generic
from django.contrib.contenttypes.models import ContentType
from django.utils.translation import ugettext_lazy as _
from django.contrib.auth.models import User

from django.db.models.signals import pre_save
from django.dispatch import receiver

"""
from mptt.managers import TreeManager
from mptt.models import MPTTModel

TODO: BaseModel with versionning support
class BaseManager(models.Manager):
    def get_query_set(self):
        return super(BaseManager, self).get_query_set().filter(deleted_flag=False)

    def all_with_deleted(self):
        return super(BaseManager, self).get_query_set(related_id=0)

class MPTTBaseManager(BaseManager, TreeManager):
    pass

"""
def get_sentinel_user():
    return User.objects.get_or_create(username='deleted')[0]

class BaseModel(models.Model):
    created_by = models.ForeignKey(User, on_delete=models.SET(get_sentinel_user), editable=False, related_name="%(app_label)s_%(class)s_created")
    created_date = models.DateTimeField(_('Added date'), auto_now_add=True)
    last_updated_by = models.ForeignKey(User, on_delete=models.SET(get_sentinel_user), editable=False, related_name="%(app_label)s_%(class)s_updated")
    last_updated_date = models.DateTimeField(_('Last update date'), auto_now=True)
    """
    related_id = models.IntegerField(default=0,editable=False)
    deleted_flag = models.BooleanField(_('Deleted'),default=False, editable=False)

    objects = BaseManager()
    
    def versions(self):
        #Returns old versions of current record
        return self.__class__.objects.filter(related_id=self.id, deleted_flag=False)

    def is_deleted(self):
        return self.deleted_flag

    def delete(self,permanent=False):
        if permanent:
            super(BaseModel,self).delete(self)
        else:
            self.deleted_flag = True
            self.save()
    """

    class Meta:
        abstract = True
        get_latest_by = "created_date"
        ordering = ("-created_date",)
        """
        FIXME: Permission must be model specific. Now it's App specific
        https://code.djangoproject.com/ticket/10686
        """
        permissions = (("can_view_deleted", _("Can view deleted rows")),)

"""
@receiver(pre_save)
def version(sender, instance, **kwargs):
    # check if model is an instance of BaseModel abstract model
    if isinstance(instance, BaseModel):
        # if the instance has no id, it is created
        current_id = instance.id
        if current_id:
            old = instance
            old.pk = None
            old.id = None
            old.related_id = current_id
            old.deleted_flag = True
            old.save()

class MPTTBaseModel(BaseModel, MPTTModel):
    _default_manager = MPTTBaseManager()

    class Meta:
        abstract = True
"""

class MetadataModel(models.Model):
    _metadata = None
    def metadata(self):
        if not self._metadata:
            self._metadata = {}
            metadata_type = ContentType.objects.get_for_model(self)
            for mt in Attribute.objects.filter(content_type__pk=metadata_type.id, object_id=self.id):
                self._metadata[mt.key] = mt.value
        
        return self._metadata

    def get_meta(self,key):
        metadata_type = ContentType.objects.get_for_model(self)
        return Attribute.objects.filter(content_type__pk=metadata_type.id, object_id=self.id, key=key)
    
    class Meta:
        abstract = True

class Attribute(BaseModel):
    content_type = models.ForeignKey(ContentType)
    object_id = models.PositiveIntegerField()
    content_object = generic.GenericForeignKey('content_type', 'object_id')
    key = models.CharField(_('Key'), max_length=50)
    value = models.TextField(_('Value'), blank=True)
    
    class Meta:
        ordering = ('content_type','key')
        verbose_name = _('Meta Data')
        verbose_name_plural = _('Meta Data')
    
    def __unicode__(self):
        return self.key




from django.shortcuts import redirect, render_to_response, get_object_or_404
from django.template import RequestContext
from django.http import Http404, HttpResponse
from django.conf import settings
from django.core.paginator import Paginator, InvalidPage, EmptyPage
from datetime import date
from models import Post,Category
from taggit.models import Tag

def index(request):
	category_list = Category.objects.all()
	
	return render_to_response('fancy/blog/index.html', 
		{ 'category_list' : category_list },context_instance=RequestContext(request))

def detail(request,slug):
	post = get_object_or_404(Post,slug=slug)
	
	if post.redirect_to:
	    return redirect(post.redirect_to)
	
	return render_to_response('fancy/blog/detail.html',{'post':post},
                                  context_instance=RequestContext(request))

def show_post_list(request,post_list,title="",archieve_type="category"):
	paginator = Paginator(post_list, 50)
	page = int(request.GET.get('page', '1'))
	
	try:
		page = int(request.GET.get('page', '1'))
	except ValueError:
		page = 1
		
	try:
		posts = paginator.page(page)
	except (EmptyPage, InvalidPage):
		posts = paginator.page(paginator.num_pages)

	return render_to_response('fancy/blog/posts.html', { 
						'post_list' : posts, 
						'title' : title,
						'archieve_type' : archieve_type
						}, context_instance=RequestContext(request) )

def tag_index(request,slug):
	tag = get_object_or_404(Tag,slug=slug)
	post_list = Post.objects.filter(tags__slug__in=[slug.lower()],status=1)
	title = tag.name
	return show_post_list(request,post_list,title,'tag')

def category_index(request,slug):
	category = get_object_or_404(Category,slug=slug)
	post_list = Post.objects.filter(categories=category,status=1)
	title = category.name
	return show_post_list(request,post_list,title,'category')

def year_index(request,year):
	post_list=Post.objects.filter(date__year=year,status=1)
	title = date( int(year), 1, 1)
	return show_post_list(request,post_list,title,"year")
		
def month_index(request,year,month):
	post_list=Post.objects.filter(date__year=year, date__month=month,status=1) 
	title = date( int(year), int(month), 1)
	return show_post_list(request,post_list,title,"month")
	
	
	


	


from django.conf.urls.defaults import patterns, include, url
from feeds import LatestEntriesFeed
import settings

urlpatterns = patterns('fancy.blog.views',
    url(r'^$', 'index', name='post_index'),
    url(r'^rss/$', LatestEntriesFeed()),
	url(r'^(?P<year>[\d]{4})/$','year_index', name='post_year_index'),
	url(r'^(?P<year>[\d]{4})/(?P<month>[\d]{2})/$','month_index', name='post_month_index'),
	url(r'^(?P<slug>[-\w]+)/$', 'detail', name='post_detail'),
    url(r'^%s/(?P<slug>[-\w]+)/$' % settings.BLOG_CATEGORY_PATH, 'category_index', name='category_index'),	
    url(r'^%s/(?P<slug>[-\w]+)/$' % settings.BLOG_TAG_PATH, 'tag_index', name='tag_index'),	
)



from django.conf.urls.defaults import *

urlpatterns = patterns('fancy.products.views',
    url(r'^$', 'main', name="products_main" ),
    url(r'^(?P<slug>[\w\-\/]+)/$', 'main_controller', name="products_full_tree" ),
)



from django.conf import settings
from django.utils.translation import ugettext_lazy as _

PAGE_TEMPLATES = getattr(settings, 'PAGE_TEMPLATES', (
    ('default', _('Default')),
))
PAGE_VERSIONING = getattr(settings, 'PAGE_VERSIONING', True)
PAGE_DEFAULT_CONTENT_TYPE = getattr(settings, 'PAGE_DEFAULT_CONTENT_TYPE', 'md')
PAGE_CONTENT_EDITORS = getattr(settings, 'PAGE_CONTENT_EDITORS', {
    'text':'textfield',
    'html':'tinymce',
    'md':'pagedown',
})
PAGE_META_CHOICES = getattr(settings, 'PAGE_META_CHOICES', None)


# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

PACKAGE = "fancy"
NAME = "django-fancy-apps"
DESCRIPTION = "Django Fancy Apps"
AUTHOR = u'Murat Çorlu'
AUTHOR_EMAIL = "muratcorlu@gmail.com"
URL = "http://github.com/muratcorlu/django-fancy-apps"
VERSION = __import__(PACKAGE).__version__


setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    #long_description=read("README.md"),
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    license="MIT",
    url=URL,
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'django >= 1.4',
        'django-taggit >= 0.8',
        'django-mptt >= 0.5.2'
    ],
)




from django.contrib import admin
from django.contrib.contenttypes import generic
from models import Attribute, BaseModel
from django.utils.translation import ugettext_lazy as _

class MetaInline(generic.GenericTabularInline):
    model = Attribute
    extra = 0

class BaseAdmin(admin.ModelAdmin):
    """
    def get_readonly_fields(self, request, obj=None):
        fs = super(BaseAdmin, self).get_readonly_fields(request, obj)
        fs += ('created_by', 'last_updated_by',)
        return fs

    def get_fieldsets(self, request, obj=None):
        fs = super(BaseAdmin, self).get_fieldsets(request, obj)
        
        fs[0][1]['fields'].remove('created_by')
        fs[0][1]['fields'].remove('last_updated_by')

        fs.extend([(_('Other informations'), {'fields':['created_by','last_updated_by'], 'classes':['collapse']})])
        return fs

    def changelist_view(self, request, extra_context=None):
        if request.user.has_perm('%s.can_view_deleted' % self.model._meta.app_label):
            if not "deleted_flag" in self.list_filter:
                self.list_filter += ("deleted_flag",)
        return super(BaseAdmin, self).changelist_view(request, extra_context)
    def queryset(self, request):
        return super(BaseAdmin, self).queryset(request).exclude(deleted_flag=True)
    """
    
    def save_model(self, request, obj, form, change):
        if not change:
            obj.created_by = request.user

        obj.last_updated_by = request.user
        obj.save()

    def save_formset(self, request, form, formset, change):
        instances = formset.save(commit=False)

        for instance in instances:
            if isinstance(instance, BaseModel): #Check if it is the correct type of inline
                if not instance.created_by_id:
                    instance.created_by = request.user
                
                instance.last_updated_by = request.user            
                instance.save()



from django.db import models
from django.utils.translation import ugettext_lazy as _
from mptt.models import MPTTModel
import settings
from fancy.gallery.models import Image, ModelWithImage
from datetime import datetime
from fancy.utils.models import MetadataModel, BaseModel
from django.contrib.contenttypes import generic

class Category(MPTTModel, BaseModel, ModelWithImage):
    name = models.CharField(_('Category name'), max_length=200)
    slug = models.SlugField(_('Slug'), max_length=200, blank=True)
    description = models.TextField(_('Description'), blank=True)
    parent = models.ForeignKey("self", related_name="children", null=True, blank=True)

    class Meta(BaseModel.Meta):
        verbose_name = _('Product category')
        verbose_name_plural = _('Product categories')
        ordering = ('name',)

    def __unicode__(self):
        return self.name

    @models.permalink
    def get_absolute_url(self):
        if not getattr(self, '_slug', None):
            slugs = [ancestor.slug for ancestor in self.get_ancestors()]
            slugs.append(self.slug)
            
            url = '/'.join(slugs)

            self._slug = url    
        return ('products_full_tree', (), {'slug' : str(self._slug) } )


class Product(MetadataModel, ModelWithImage, BaseModel):
    name = models.CharField(_('Product name'), max_length=200)
    slug = models.SlugField(_('Slug'), max_length=200, blank=True)
    price = models.DecimalField(_('Price'),max_digits=6,decimal_places=2,default=0)
    description = models.TextField(_('Description'))
    
    category = models.ForeignKey(Category, verbose_name=_('Product category'), related_name="products")

    STATUSES = (
        ('0', _('Out of stock')),
        ('1', _('In stock')),
    )
    status = models.CharField(_('Status'), max_length=1, choices=STATUSES, default='1')
    order_number = models.IntegerField(_('Order Number'),help_text=_('Ordering'),default=0)

    class Meta(BaseModel.Meta):
        verbose_name = _('Product')
        verbose_name_plural = _('Products')
        ordering = ('order_number','-id')

    def __unicode__(self):
        return self.name

    def save(self, *args, **kwargs):
        if self.slug == '':
            self.slug = slugify(self.name)

        super(Product, self).save(*args, **kwargs) # Call the "real" save() method.
    
    def can_order_multiple(self):
        return self.max_count > 1
        
    def get_price_as_cent(self):
        return int(self.price * 100)

    @models.permalink
    def get_absolute_url(self):
        if not getattr(self, '_slug', None):
            slugs = [ancestor.slug for ancestor in self.category.get_ancestors()]
            slugs.append(self.category.slug)
            slugs.append(self.slug)
            
            url = '/'.join(slugs)

            self._slug = url    
        return ('products_full_tree', (), {'slug' : str(self._slug) } )



from django.db import models
from settings import GALLERY_ORIGINAL_IMAGESIZE
from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from fancy.utils import slugify
from fancy.utils.models import BaseModel
import os
from PIL import Image as PILImage
from helpers import get_upload_path
from taggit.managers import TaggableManager
from django.contrib.contenttypes import generic
from django.contrib.contenttypes.models import ContentType

ALBUM_STATUSES = (
    (0, _('Private')),
    (1, _('Public')),
)

class Image(BaseModel):
    content_type = models.ForeignKey(ContentType)
    object_id = models.PositiveIntegerField()
    content_object = generic.GenericForeignKey('content_type', 'object_id')

    name = models.CharField(_('Item name'), max_length=200, blank=True)
    image = models.ImageField(_('Image'), upload_to=get_upload_path)
    slug = models.SlugField(_('Slug'), max_length=200, blank=True)
    description = models.TextField(_('Description'), blank=True)
    order_number = models.IntegerField(_('Order number'), default=0)
    is_cover = models.BooleanField(_('Cover photo'))

    #tags = TaggableManager(blank=True)
        
    class Meta(BaseModel.Meta):
        verbose_name = _('Image')
        verbose_name_plural = _('Images')

    def save(self, *args, **kwargs):
        if self.image and not GALLERY_ORIGINAL_IMAGESIZE == 0:
            width, height = GALLERY_ORIGINAL_IMAGESIZE.split('x')
            super(Image, self).save(*args, **kwargs)

            filename = os.path.join( settings.MEDIA_ROOT, self.image.name )
            image = PILImage.open(filename)

            image.thumbnail((int(width), int(height)), PILImage.ANTIALIAS)
            image.save(filename)
        
        if not self.slug:
            self.slug = slugify(self.name)
        
        super(Image, self).save(*args, **kwargs)

    def __unicode__(self):
        return self.image.url

    @models.permalink
    def get_absolute_link(self):
        return ('album_item_detail', (), {'album_slug':self.album.slug, 'album_item_slug' : self.slug } )

# If sorl-thumbnail app is installed, bind image delete signal to thumbnail deletions
if 'sorl.thumbnail' in settings.INSTALLED_APPS:
    from sorl.thumbnail import delete
    from django.db.models.signals import post_delete
    from django.dispatch import receiver

    @receiver(post_delete, sender=Image)
    def delete_image_files(sender, instance, **kwargs):
        # delete thumbnails
        delete(instance.image)

class ModelWithImage(models.Model):
    images = generic.GenericRelation(Image)

    def cover(self):
        try:
            cover_item = self.images.get(is_cover=True)
        except:
            cover_item = self.images.latest()
        
        return cover_item

    class Meta:
        abstract = True


class Album(BaseModel, ModelWithImage):
    name = models.CharField(_('Album Name'), max_length=200)
    description = models.TextField(_('Description'), blank=True)
    slug = models.SlugField(_('Slug'), max_length=200, blank=True)
    status = models.SmallIntegerField(_('Status'),choices=ALBUM_STATUSES)
    
    class Meta(BaseModel.Meta):
        verbose_name = _('Album')
        verbose_name_plural = _('Albums')

    def __unicode__(self):
        return self.name
    
    @models.permalink
    def get_absolute_url(self):
     return ('album_detail', (), {'slug' : self.slug })



from django.db import models, IntegrityError, transaction
from datetime import datetime
from django.utils.translation import ugettext_lazy as _
from django.contrib.auth.models import User
from fancy.utils.models import BaseModel, MetadataModel, get_sentinel_user
from fancy.utils import slugify
from mptt.models import MPTTModel
from taggit.managers import TaggableManager

class Post(MetadataModel,BaseModel):
    title = models.CharField(_('Title'),max_length=200)
    slug = models.SlugField(_('Slug'), max_length=200, blank=True, unique=True)
    author = models.ForeignKey(User, on_delete=models.SET(get_sentinel_user))
    content = models.TextField(_('Post Content'),blank=True)
    date = models.DateTimeField(_('Publish Date'), default=datetime.now())
    enable_comments = models.BooleanField(default=True)
    categories = models.ManyToManyField('Category')
    redirect_to = models.CharField(_('Redirect to'),help_text=_("Redirect this url to another url instead of showing"),blank=True,null=True,max_length=100)

    PUB_STATUS = (
        (0, _('Draft')),
        (1, _('Published')),
    )
    status = models.IntegerField(_('Status'),choices=PUB_STATUS, default=0)

    tags = TaggableManager(blank=True)

    class Meta(BaseModel.Meta):
        ordering = ('-date',)
        get_latest_by = 'date'
        verbose_name = _('Post')
        verbose_name_plural = _('Posts')

    def save(self, *args, **kwargs):
        slug = self.slug
        if slug == '':
            self.slug = slug = slugify(self.title)

        i = 0
        while True:
            try:
                savepoint = transaction.savepoint()
                res = super(Post, self).save(*args, **kwargs)
                transaction.savepoint_commit(savepoint)
                return res
            except IntegrityError:
                transaction.savepoint_rollback(savepoint)
                i += 1
                self.slug = '%s-%d' % (slug, i)

        super(Post, self).save(*args, **kwargs) # Call the "real" save() method.

    def __unicode__(self):
        return self.title

    @models.permalink
    def get_absolute_url(self):
        return ('post_detail', (), {'slug' : self.slug } )

    def get_link(self):
        if self.redirect_to:
            return self.redirect_to

        return self.get_absolute_url()

    def get_previous(self):
        return self.get_previous_by_date(status__exact=1)

    def get_next(self):
        return self.get_next_by_date(status__exact=1)

    def get_content(self):
        return self.content

class Category(MPTTModel,BaseModel):
    name = models.CharField(_('Category Name'), max_length=50)
    slug = models.SlugField(_('Slug'), max_length=200)
    description = models.TextField(_('Description'), blank=True)
    parent = models.ForeignKey("self", related_name="children", null=True, blank=True)

    class Meta(BaseModel.Meta):
        ordering = ('name',)
        verbose_name = _('Category')
        verbose_name_plural = _('Categories')

    def __unicode__(self):
        return self.name

    @models.permalink
    def get_absolute_url(self):
        return ('category_index', (), {'slug' : self.slug } )

    def get_last_post(self):
        return Post.objects.filter(categories=self,status=1)[0]

    def post_count(self):
        return Post.objects.filter(categories=self,status=1).count()

    def last_post_date(self):
        return self.get_last_post().date



from django.shortcuts import render_to_response, get_object_or_404, redirect
from django.template import RequestContext
from django.template.loader import render_to_string
from django.http import Http404, HttpResponse
from django.conf import settings
import settings as appsettings

#from fancy.utils.mail import send_html_mail
from django.utils.html import strip_tags

def send_mail(subject, from_email, recipients, message_html):
    if "mailer" in settings.INSTALLED_APPS:
        from mailer import send_html_mail
        send_html_mail(subject=subject, message=strip_tags(message_html), message_html=message_html, from_email=from_email, recipient_list=recipients)
    else:
        from django.core.mail import EmailMultiAlternatives

        msg = EmailMultiAlternatives(subject, strip_tags(message_html), from_email, recipients)
        msg.attach_alternative(message_html, "text/html")
        msg.content_subtype = "html"
        msg.send()

def get_mail_content(request):
    tpl = request.POST.get('_tpl', 'default')
    fields = dict((k, v) for k, v in request.POST.items() if k[0] != '_')
    
    return render_to_string("fancy/mailform/mail/%s.html" % tpl, {'fields':fields})

def post_form(request):
    message_html = get_mail_content(request)
    
    from_email = appsettings.FORM_FROM
    recipients = appsettings.FORM_RECIPIENTS
    redirect_to = request.POST.get('_success_url')
    subject = request.POST.get('_subject', appsettings.FORM_SUBJECT)
    
    send_mail(subject, from_email, recipients, message_html)
    
    return redirect(redirect_to)


from django import forms
from mptt.forms import TreeNodeChoiceField
from models import Category

class CategoryForm(forms.ModelForm):
    
    parent = TreeNodeChoiceField(queryset=Category.tree.all(), level_indicator=3*unichr(160), empty_label='---------', required=False)
    
    class Meta:
        model = Category
        


from django import template
from django.template.loader import render_to_string
from django.utils.safestring import mark_safe

try:
	from BeautifulSoup import BeautifulSoup
except ImportError:
	from beautifulsoup import BeautifulSoup

register = template.Library()

@register.filter
def render_sub_pages(value):
    content = BeautifulSoup(value, selfClosingTags=['sub_pages','img','br','input','meta','link','hr'])

    for inline in content.findAll('sub_pages'):
        try:
            template = inline["template"]
        except:
            template = "default.html"
        
        inline.replaceWith(render_to_string("fancy/pages/%s" %template, ))

    return mark_safe(content)

def render_inline_sub_pages(value):
    return "inlines(value)"

@register.filter
def render_inlines(value):
	content = BeautifulSoup(value, selfClosingTags=['inline','img','br','input','meta','link','hr'])

	for inline in content.findAll('inline'):
		params = {}
		for attr, value in inline.attrs:
			params[attr] = value

		id = inline["id"]
		try:
			template = inline["template"]
		except:
			template = inline["id"]

		inline.replaceWith(render_to_string("fancy/pages/inline_%s.html" % template, params ))
	
	return mark_safe(content)





from django import forms
from django.utils.translation import ugettext_lazy as _

from mptt.forms import TreeNodeChoiceField

from models import Page

class PageForm(forms.ModelForm):

    parent = TreeNodeChoiceField(queryset=Page.tree.all(), level_indicator=3*unichr(160), empty_label='---------', required=False)

    class Meta:
        model = Page

